summaryrefslogtreecommitdiff
path: root/var/spack/repos/builtin/packages/xsdk/package.py
diff options
context:
space:
mode:
Diffstat (limited to 'var/spack/repos/builtin/packages/xsdk/package.py')
-rw-r--r--var/spack/repos/builtin/packages/xsdk/package.py53
1 files changed, 31 insertions, 22 deletions
diff --git a/var/spack/repos/builtin/packages/xsdk/package.py b/var/spack/repos/builtin/packages/xsdk/package.py
index e99952c655..b0e6948734 100644
--- a/var/spack/repos/builtin/packages/xsdk/package.py
+++ b/var/spack/repos/builtin/packages/xsdk/package.py
@@ -1,4 +1,4 @@
-# Copyright 2013-2020 Lawrence Livermore National Security, LLC and other
+# Copyright 2013-2021 Lawrence Livermore National Security, LLC and other
# Spack Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)
@@ -32,6 +32,7 @@ class Xsdk(BundlePackage):
variant('omega-h', default=True, description='Enable omega-h package build')
variant('strumpack', default=True, description='Enable strumpack package build')
variant('dealii', default=True, description='Enable dealii package build')
+ variant('alquimia', default=True, description='Enable alquimia package build')
variant('phist', default=True, description='Enable phist package build')
variant('ginkgo', default=True, description='Enable ginkgo package build')
variant('libensemble', default=True, description='Enable py-libensemble package build')
@@ -40,6 +41,7 @@ class Xsdk(BundlePackage):
variant('butterflypack', default=True, description='Enable butterflypack package build')
variant('heffte', default=True, description='Enable heffte package build')
variant('slate', default=True, description='Enable slate package build')
+ variant('arborx', default=True, description='Enable ArborX build')
depends_on('hypre@develop+superlu-dist+shared', when='@develop')
depends_on('hypre@2.20.0+superlu-dist+shared', when='@0.6.0')
@@ -61,7 +63,7 @@ class Xsdk(BundlePackage):
depends_on('superlu-dist@5.2.2', when='@0.3.0')
depends_on('superlu-dist@xsdk-0.2.0', when='@xsdk-0.2.0')
- depends_on('trilinos@develop+hypre+superlu-dist+metis+hdf5~mumps+boost~suite-sparse+tpetra+nox+ifpack2+zoltan2+amesos2~exodus+dtk+intrepid2+shards gotype=int',
+ depends_on('trilinos@develop+hypre+superlu-dist+metis+hdf5~mumps+boost~suite-sparse+tpetra+nox+ifpack2+zoltan2+amesos2~exodus~dtk+intrepid2+shards+stratimikos gotype=int cxxstd=14',
when='@develop +trilinos')
depends_on('trilinos@13.0.1+hypre+superlu-dist+metis+hdf5~mumps+boost~suite-sparse+tpetra+nox+ifpack2+zoltan2+amesos2~exodus~dtk+intrepid2+shards gotype=int',
when='@0.6.0 +trilinos')
@@ -74,12 +76,13 @@ class Xsdk(BundlePackage):
depends_on('trilinos@xsdk-0.2.0+hypre+superlu-dist+metis+hdf5~mumps+boost~suite-sparse~tpetra~ifpack2~zoltan2~amesos2~exodus',
when='@xsdk-0.2.0 +trilinos')
+ depends_on('datatransferkit@master', when='@develop +trilinos +datatransferkit')
depends_on('datatransferkit@3.1-rc2', when='@0.6.0 +trilinos +datatransferkit')
depends_on('petsc +trilinos', when='+trilinos')
depends_on('petsc +cuda', when='+cuda @0.6.0:')
depends_on('petsc +batch', when='platform=cray @0.5.0:')
- depends_on('petsc@develop+mpi+hypre+superlu-dist+metis+hdf5~mumps+double~int64',
+ depends_on('petsc@main+mpi+hypre+superlu-dist+metis+hdf5~mumps+double~int64',
when='@develop')
depends_on('petsc@3.14.1+mpi+hypre+superlu-dist+metis+hdf5~mumps+double~int64',
when='@0.6.0')
@@ -94,7 +97,7 @@ class Xsdk(BundlePackage):
depends_on('dealii +trilinos~adol-c', when='+trilinos +dealii')
depends_on('dealii ~trilinos', when='~trilinos +dealii')
- depends_on('dealii@develop~assimp~python~doc~gmsh+petsc+slepc+mpi~int64+hdf5~netcdf+metis~sundials~ginkgo~symengine', when='@develop +dealii')
+ depends_on('dealii@master~assimp~python~doc~gmsh+petsc+slepc+mpi~int64+hdf5~netcdf+metis~sundials~ginkgo~symengine~nanoflann', when='@develop +dealii')
depends_on('dealii@9.2.0~assimp~python~doc~gmsh+petsc+slepc+mpi~int64+hdf5~netcdf+metis~sundials~ginkgo~symengine', when='@0.6.0 +dealii')
depends_on('dealii@9.1.1~assimp~python~doc~gmsh+petsc+slepc+mpi~int64+hdf5~netcdf+metis~sundials~ginkgo~symengine', when='@0.5.0 +dealii')
depends_on('dealii@9.0.1~assimp~python~doc~gmsh+petsc~slepc+mpi~int64+hdf5~netcdf+metis~ginkgo~symengine', when='@0.4.0 +dealii')
@@ -106,12 +109,12 @@ class Xsdk(BundlePackage):
depends_on('pflotran@xsdk-0.3.0', when='@0.3.0')
depends_on('pflotran@xsdk-0.2.0', when='@xsdk-0.2.0')
- depends_on('alquimia@develop', when='@develop')
- depends_on('alquimia@xsdk-0.6.0', when='@0.6.0')
- depends_on('alquimia@xsdk-0.5.0', when='@0.5.0')
- depends_on('alquimia@xsdk-0.4.0', when='@0.4.0')
- depends_on('alquimia@xsdk-0.3.0', when='@0.3.0')
- depends_on('alquimia@xsdk-0.2.0', when='@xsdk-0.2.0')
+ depends_on('alquimia@develop', when='@develop +alquimia')
+ depends_on('alquimia@xsdk-0.6.0', when='@0.6.0 +alquimia')
+ depends_on('alquimia@xsdk-0.5.0', when='@0.5.0 +alquimia ')
+ depends_on('alquimia@xsdk-0.4.0', when='@0.4.0 +alquimia')
+ depends_on('alquimia@xsdk-0.3.0', when='@0.3.0 +alquimia')
+ depends_on('alquimia@xsdk-0.2.0', when='@xsdk-0.2.0 +alquimia')
depends_on('sundials +cuda', when='+cuda @0.6.0:')
depends_on('sundials +trilinos', when='+trilinos @0.6.0:')
@@ -141,25 +144,25 @@ class Xsdk(BundlePackage):
depends_on('amrex@18.10.1', when='@0.4.0 %intel')
depends_on('amrex@18.10.1', when='@0.4.0 %gcc')
- depends_on('slepc@develop', when='@develop')
+ depends_on('slepc@main', when='@develop')
depends_on('slepc@3.14.0', when='@0.6.0')
depends_on('slepc@3.12.0', when='@0.5.0')
depends_on('slepc@3.10.1', when='@0.4.0')
depends_on('omega-h +trilinos', when='+trilinos +omega-h')
depends_on('omega-h ~trilinos', when='~trilinos +omega-h')
- depends_on('omega-h@develop', when='@develop +omega-h')
+ depends_on('omega-h@main', when='@develop +omega-h')
depends_on('omega-h@9.32.5', when='@0.6.0 +omega-h')
depends_on('omega-h@9.29.0', when='@0.5.0 +omega-h')
depends_on('omega-h@9.19.1', when='@0.4.0 +omega-h')
- depends_on('strumpack ~cuda', when='~cuda @0.6.0:')
- depends_on('strumpack@master', when='@develop +strumpack')
- depends_on('strumpack@5.0.0', when='@0.6.0 +strumpack')
- depends_on('strumpack@3.3.0', when='@0.5.0 +strumpack')
- depends_on('strumpack@3.1.1', when='@0.4.0 +strumpack')
+ depends_on('strumpack ~cuda', when='~cuda @0.6.0: +strumpack')
+ depends_on('strumpack@master~slate~openmp', when='@develop +strumpack')
+ depends_on('strumpack@5.0.0~slate~openmp', when='@0.6.0 +strumpack')
+ depends_on('strumpack@3.3.0~slate~openmp', when='@0.5.0 +strumpack')
+ depends_on('strumpack@3.1.1~slate~openmp', when='@0.4.0 +strumpack')
- depends_on('pumi@develop', when='@develop')
+ depends_on('pumi@master', when='@develop')
depends_on('pumi@2.2.5', when='@0.6.0')
depends_on('pumi@2.2.1', when='@0.5.0')
depends_on('pumi@2.2.0', when='@0.4.0')
@@ -174,15 +177,17 @@ class Xsdk(BundlePackage):
depends_on('tasmanian@6.0+xsdkflags+blas~openmp', when='@0.4.0')
depends_on('tasmanian@6.0+xsdkflags+blas+cuda+magma~openmp', when='@0.4.0 +cuda')
+ depends_on('arborx@1.0', when='@develop +arborx')
+
# the Fortran 2003 bindings of phist require python@3:, but this
# creates a conflict with other packages like petsc@develop. Actually
# these are type='build' dependencies, but spack reports a conflict anyway.
# This will be fixed once the new concretizer becomes available
# (says @adamjstewart)
depends_on('phist kernel_lib=tpetra', when='+trilinos +phist')
depends_on('phist kernel_lib=petsc', when='~trilinos +phist')
- depends_on('phist@develop ~fortran ~scamac ~host', when='@develop +phist')
+ depends_on('phist@develop ~fortran ~scamac ~openmp ~host ~int64', when='@develop +phist')
depends_on('phist@1.9.3 ~fortran ~scamac ~openmp ~host ~int64', when='@0.6.0 +phist')
depends_on('phist@1.8.0 ~fortran ~scamac ~openmp ~host ~int64', when='@0.5.0 +phist')
depends_on('phist@1.7.5 ~fortran ~scamac ~openmp ~host ~int64', when='@0.4.0 +phist')
@@ -195,7 +200,9 @@ class Xsdk(BundlePackage):
depends_on('ginkgo@1.1.0 ~openmp+cuda', when='@0.5.0 +cuda +ginkgo')
depends_on('py-libensemble@develop+petsc4py', type='run', when='@develop +libensemble')
+ depends_on('py-petsc4py@main', type='run', when='@develop +libensemble')
depends_on('py-libensemble@0.7.1+petsc4py', type='run', when='@0.6.0 +libensemble')
+ depends_on('py-petsc4py@3.14.0', type='run', when='@0.6.0 +libensemble')
depends_on('py-libensemble@0.5.2+petsc4py', type='run', when='@0.5.0 +libensemble')
depends_on('py-petsc4py@3.12.0', type='run', when='@0.5.0 +libensemble')
@@ -213,8 +220,10 @@ class Xsdk(BundlePackage):
depends_on('heffte@develop+fftw', when='@develop +heffte')
depends_on('heffte@2.0.0+fftw', when='@0.6.0 +heffte')
- depends_on('slate@2020.10.00 ~cuda', when='~cuda +slate %gcc@6.0:')
- depends_on('slate@2020.10.00 +cuda', when='+cuda +slate %gcc@6.0:')
+ depends_on('slate@master ~cuda', when='@develop ~cuda +slate %gcc@6.0:')
+ depends_on('slate@master +cuda', when='@develop +cuda +slate %gcc@6.0:')
+ depends_on('slate@2020.10.00 ~cuda', when='@0.6.0 ~cuda +slate %gcc@6.0:')
+ depends_on('slate@2020.10.00 +cuda', when='@0.6.0 +cuda +slate %gcc@6.0:')
# xSDKTrilinos depends on the version of Trilinos built with
# +tpetra which is turned off for faster xSDK
@@ -174,15 +177,17 @@ class Xsdk(BundlePackage):
# the Fortran 2003 bindings of phist require python@3:, but this
- # creates a conflict with other packages like petsc@develop. Actually
+ # creates a conflict with other packages like petsc@main. Actually
# these are type='build' dependencies, but spack reports a conflict anyway.
# This will be fixed once the new concretizer becomes available